Compartmental Model
===================

.. module:: icomo

Defining a compartmental model
-------------------------------


.. autoclass:: CompModel
    :exclude-members: y, dy, edges, __weakref__
    :members:

Helper functions
----------------

.. autofunction:: erlang_kernel

.. autofunction:: delayed_copy_kernel
